#ifndef NT2_INCLUDE_FUNCTIONS_NORMCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NORMCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/normcdf.hpp>

#endif
